@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3.1     2006/12/08
+ * Version: 1.3     2006/11/11
  *
  */
 #include <stdio.h>
@@ -38,7 +38,7 @@
 #define KEYWORD_ALLOW_CONNECT            "allow_connect "
 #define KEYWORD_ALLOW_NETWORK            "allow_network "
 #define KEYWORD_ALLOW_SIGNAL             "allow_signal "
-#define KEYWORD_DOMAIN_KEEPER            "keep_domain "
+#define KEYWORD_TRUST_DOMAIN             "trust_domain "
 #define KEYWORD_ALLOW_READ               "allow_read "
 #define KEYWORD_INITIALIZER              "initializer "
 #define KEYWORD_ALIAS                    "alias "
@@ -58,7 +58,7 @@
 #define KEYWORD_ALLOW_CONNECT_LEN      (sizeof(KEYWORD_ALLOW_CONNECT) - 1)
 #define KEYWORD_ALLOW_NETWORK_LEN      (sizeof(KEYWORD_ALLOW_NETWORK) - 1)
 #define KEYWORD_ALLOW_SIGNAL_LEN       (sizeof(KEYWORD_ALLOW_SIGNAL) - 1)
-#define KEYWORD_DOMAIN_KEEPER_LEN      (sizeof(KEYWORD_DOMAIN_KEEPER) - 1)
+#define KEYWORD_TRUST_DOMAIN_LEN       (sizeof(KEYWORD_TRUST_DOMAIN) - 1)
 #define KEYWORD_ALLOW_READ_LEN         (sizeof(KEYWORD_ALLOW_READ) - 1)
 #define KEYWORD_INITIALIZER_LEN        (sizeof(KEYWORD_INITIALIZER) - 1)
 #define KEYWORD_ALIAS_LEN              (sizeof(KEYWORD_ALIAS) - 1)
@@ -673,8 +673,8 @@ int main(int argc, char *argv[]) {
 			if (strncmp(buffer, KEYWORD_DELETE, KEYWORD_DELETE_LEN) == 0) {
 				RemoveHeader(buffer, KEYWORD_DELETE_LEN);
 			}
-			if (strncmp(buffer, KEYWORD_DOMAIN_KEEPER, KEYWORD_DOMAIN_KEEPER_LEN) == 0) {
-				RemoveHeader(buffer, KEYWORD_DOMAIN_KEEPER_LEN);
+			if (strncmp(buffer, KEYWORD_TRUST_DOMAIN, KEYWORD_TRUST_DOMAIN_LEN) == 0) {
+				RemoveHeader(buffer, KEYWORD_TRUST_DOMAIN_LEN);
 				if (!IsCorrectDomain(buffer)) {
 					printf("%u: ERROR: '%s' is a bad domainname.\n", line, buffer); errors++;
 				}
