@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3.1     2007/01/07
+ * Version: 1.3     2006/11/11
  *
  */
 #include <stdio.h>
@@ -118,23 +118,13 @@ static inline int strendswith(const char *name, const char *tail) {
 	return len >= 0 && strcmp(name + len, tail) == 0;
 }
 
-static int getch2(void) {
-	static int c0 = 0, c1 = 0, c2 = 0, c3 = 0, len = 0;
-	if (len > 0) { c0 = c1; c1 = c2; c2 = c3; len--; return c0; }
-	c0 = getch(); if (c0 != 0x1B) return c0;
-	c1 = getch(); if (c1 != '[') { len = 1; return c0; }
-	c2 = getch(); if (c2 != '5' && c2 != '6') { len = 2; return c0; }
-	c3 = getch(); if (c3 != '~') { len = 3; return c0; }
-	return c2 == '5' ? KEY_PPAGE : KEY_NPAGE;
-}
-
 static void ReadGenericPolicy(void);
 static void ReadDomainPolicy(void);
 static int FindOrAssignNewDomain(const char *domainname);
 static int FindDomain(const char *domainname);
 static void NormalizeLine(unsigned char *buffer);
 static char *DomainName(const int index);
-static int IsDomainKeeper(const int index);
+static int IsTrustedDomain(const int index);
 static int IsInitializer(const char *filename);
 static int IsInitializerDomain(const int index);
 static int IsVirtualDomain(const int index);
@@ -169,18 +159,20 @@ typedef struct domain_info {
 } DOMAIN_INFO;
 static DOMAIN_INFO *domain_list = NULL;
 static int domain_list_count = 0;
-static char **domain_keepers = NULL;
-static int domain_keepers_count = 0;
+static char **trusted_domainnames = NULL;
+static int trusted_domainnames_count = 0;
 static char **initializers = NULL;
 static int initializers_count = 0;
 
 ///////////////////////////  ACL HANDLER  //////////////////////////////
 
-static int IsDomainKeeper(const int index) {
+static int IsTrustedDomain(const int index) {
 	int i;
 	char *domainname = domain_list[index].domainname;
-	for (i = 0; i < domain_keepers_count; i++) {
-		if (strcmp(domainname, domain_keepers[i]) == 0) return 1;
+	for (i = 0; i < trusted_domainnames_count; i++) {
+		const int len = strlen(trusted_domainnames[i]);
+		if (strncmp(domainname, trusted_domainnames[i], len)) continue;
+		if (domainname[len] == ' ' || domainname[len] == '\0') return 1;
 	}
 	return 0;
 }
@@ -391,10 +383,10 @@ static void ReadDomainPolicy(void) {
 	int i, j;
 	while (domain_list_count) free(domain_list[--domain_list_count].domainname);
 	while (initializers_count) free(initializers[--initializers_count]);
-	while (domain_keepers_count) free(domain_keepers[--domain_keepers_count]);
+	while (trusted_domainnames_count) free(trusted_domainnames[--trusted_domainnames_count]);
 	FindOrAssignNewDomain(ROOT_NAME);
 
-	// Load initializer list, domain_keeper list.
+	// Load initializer list, trusted domain list.
 	if ((fp = open_read(EXCEPTION_POLICY_FILE)) != NULL) {
 		get();
 		while (memset(buffer, 0, sizeof(buffer)), fgets(buffer, sizeof(buffer) - 1, fp) != NULL) {
@@ -407,11 +399,11 @@ static void ReadDomainPolicy(void) {
 				if (!IsCorrectPath(buffer, 0)) continue;
 				if ((initializers = (char **) realloc(initializers, (initializers_count + 1) * sizeof(char *))) == NULL
 					|| (initializers[initializers_count++] = strdup(buffer)) == NULL) OutOfMemory();
-			} else if (strncmp(buffer, "keep_domain ", 12) == 0) {
-				memmove(buffer, buffer + 12, strlen(buffer + 12) + 1);
+			} else if (strncmp(buffer, "trust_domain ", 13) == 0) {
+				memmove(buffer, buffer + 13, strlen(buffer + 13) + 1);
 				if (!IsCorrectDomain(buffer)) continue;
-				if ((domain_keepers = (char **) realloc(domain_keepers, (domain_keepers_count + 1) * sizeof(char *))) == NULL
-					|| (domain_keepers[domain_keepers_count++] = strdup(buffer)) == NULL) OutOfMemory();
+				if ((trusted_domainnames = (char **) realloc(trusted_domainnames, (trusted_domainnames_count + 1) * sizeof(char *))) == NULL
+					|| (trusted_domainnames[trusted_domainnames_count++] = strdup(buffer)) == NULL) OutOfMemory();
 			}
 		}
 		put();
@@ -429,21 +421,18 @@ static void ReadDomainPolicy(void) {
 			NormalizeLine(buffer);
 			if (IsDomainDef(buffer)) {
 				index = FindOrAssignNewDomain(buffer);
-			} else if (index >= 0 && (atoi(buffer) & 1) == 1 && (cp = strchr(buffer, ' ')) != NULL) {
-				char *cp2 = strstr(cp + 1, " if ");
-				if (cp2) *cp2 = '\0';
-				if (IsCorrectPath(cp + 1, 0) && !strendswith(cp + 1, "/") && IsInitializer(cp + 1)) {
-					int virtual_index;
-					static char buffer2[MAXBUFSIZE];
-					memset(buffer2, 0, sizeof(buffer2));
-					snprintf(buffer2, sizeof(buffer2) - 1, "%s %s", domain_list[index].domainname, cp + 1);
-					NormalizeLine(buffer2);
-					if ((virtual_index = FindOrAssignNewDomain(buffer2)) == EOF) {
-						fprintf(stderr, "ERROR: Can't create domain for '%s'.\n", buffer2);
-						exit(127);
-					}
-					domain_list[virtual_index].is_virtual = 1;
+			} else if (index >= 0 && (atoi(buffer) & 1) == 1 && (cp = strchr(buffer, ' ')) != NULL &&
+					   IsCorrectPath(cp + 1, 0) && !strendswith(cp + 1, "/") && IsInitializer(cp + 1)) {
+				int virtual_index;
+				static char buffer2[MAXBUFSIZE];
+				memset(buffer2, 0, sizeof(buffer2));
+				snprintf(buffer2, sizeof(buffer2) - 1, "%s %s", domain_list[index].domainname, cp + 1);
+				NormalizeLine(buffer2);
+				if ((virtual_index = FindOrAssignNewDomain(buffer2)) == EOF) {
+					fprintf(stderr, "ERROR: Can't create domain for '%s'.\n", buffer2);
+					exit(127);
 				}
+				domain_list[virtual_index].is_virtual = 1;
 			}
 		}
 		put();
@@ -513,7 +502,7 @@ static void ShowList(void) {
 		if (index >= list_item_count[current_screen]) break;
 		if (current_screen == SCREEN_DOMAIN_LIST) {
 			char *sp, *cp;
-			mvprintw(header_lines + i, 0, "%5d: %c%c ", index, IsDomainKeeper(index) ? '#' : ' ', IsInitializerDomain(index) ? '*' : ' ');
+			mvprintw(header_lines + i, 0, "%5d: %c%c ", index, IsTrustedDomain(index) ? '#' : ' ', IsInitializerDomain(index) ? '*' : ' ');
 			sp = DomainName(index);
 			while ((cp = strchr(sp, ' ')) != NULL) { printw("    "); sp = cp + 1; }
 			printw("%s", sp);
@@ -527,7 +516,6 @@ static void ShowList(void) {
 		} else {
 			mvprintw(header_lines + i, 0, "%5d: %s", index, generic_acl_list[index]);
 		}
-		clrtoeol();
 	}
 	ShowCurrent();
 }
@@ -647,7 +635,7 @@ static int GenericListLoop(void) {
 	AdjustCursorPos(generic_acl_list_count);
 	ShowList();
 	while (1) {
-		const int c = getch2();
+		const int c = getch();
 		SaveCursorPos(current_screen);
 		if (c == 'q' || c == 'Q') return MAXSCREEN;
 		if (current_screen == SCREEN_ACL_LIST) {
@@ -671,6 +659,7 @@ static int GenericListLoop(void) {
 			DownArrowKey();
 			break;
 		case KEY_PPAGE:
+		case KEY_DC:
 			PageUpKey();
 			break;
 		case KEY_NPAGE:
@@ -699,7 +688,7 @@ static int GenericListLoop(void) {
 				get();
 				mvprintw(window_height - 1, 0, "Enter new entry> "); clrtoeol(); refresh(); echo();
 				memset(buffer, 0, sizeof(buffer));
-				scrollok(stdscr, 1); getnstr(buffer, sizeof(buffer) - 1); scrollok(stdscr, 0); noecho();
+				getnstr(buffer, sizeof(buffer) - 1); noecho();
 				NormalizeLine(buffer);
 				if (buffer[0]) {
 					const int fd = open_write(policy_file);
@@ -728,7 +717,7 @@ static int DomainListLoop(void) {
 	AdjustCursorPos(domain_list_count);
 	ShowList();
 	while (1) {
-		const int c = getch2();
+		const int c = getch();
 		SaveCursorPos(current_screen);
 		if (c == 'q' || c == 'Q') return MAXSCREEN;
 		if (c == '\t') return SCREEN_SYSTEM_LIST;
@@ -745,6 +734,7 @@ static int DomainListLoop(void) {
 			DownArrowKey();
 			break;
 		case KEY_PPAGE:
+		case KEY_DC:
 			PageUpKey();
 			break;
 		case KEY_NPAGE:
@@ -756,7 +746,7 @@ static int DomainListLoop(void) {
 			input_path:
 				mvprintw(window_height - 1, 0, "Search> "); clrtoeol(); refresh(); echo();
 				memset(history.search_buffer, 0, sizeof(history.search_buffer));
-				scrollok(stdscr, 1); getnstr(history.search_buffer, sizeof(history.search_buffer) - 1); scrollok(stdscr, 0); noecho();
+				getnstr(history.search_buffer, sizeof(history.search_buffer) - 1); noecho();
 				NormalizeLine(history.search_buffer);
 				if (history.search_buffer[0]) {
 					for (i = 0; i < list_item_count[current_screen]; i++) {
@@ -831,7 +821,7 @@ static int DomainListLoop(void) {
 					get();
 					mvprintw(window_height - 1, 0, "Enter new entry> "); clrtoeol(); refresh(); echo();
 					memset(buffer, 0, sizeof(buffer));
-					scrollok(stdscr, 1); getnstr(buffer, sizeof(buffer) - 1); scrollok(stdscr, 0); noecho();
+					getnstr(buffer, sizeof(buffer) - 1); noecho();
 					NormalizeLine(buffer);
 					if (IsCorrectPath(buffer, 0) && !IsInitializer(buffer)) {
 						const int fd = open_write(DOMAIN_POLICY_FILE);
@@ -857,7 +847,7 @@ static int DomainListLoop(void) {
 					clrtoeol();
 					refresh();
 					do {
-						c = getch2();
+						c = getch();
 					} while (!(c == 'Y' || c == 'y' || c == 'N' || c == 'n' || c == EOF));
 					ResizeWindow();
 					if (c == 'Y' || c == 'y') {
@@ -985,6 +975,7 @@ int main(int argc, char *argv[]) {
 			close(fd1); close(fd2); close(fd3);
 		}
 	}
+	setenv("TERM", "linux", 1);
 	initscr();
 	cbreak();
 	noecho();
